@@ -26,12 +26,15 @@ App Handler
 
 from __future__ import unicode_literals, absolute_import
 
+import os
 # import re
+import tempfile
 
 import six
 from sqlalchemy import orm
 
 from rattail.util import load_object
+from rattail.files import temp_path
 
 
 class AppHandler(object):
@@ -70,6 +73,12 @@ class AppHandler(object):
             self.feature_handler = FeatureHandler(self.config, **kwargs)
         return self.feature_handler
 
+    def get_people_handler(self, **kwargs):
+        if not hasattr(self, 'people_handler'):
+            from rattail.people import get_people_handler
+            self.people_handler = get_people_handler(self.config, **kwargs)
+        return self.people_handler
+
     def get_products_handler(self, **kwargs):
         if not hasattr(self, 'products_handler'):
             from rattail.products import get_products_handler
@@ -97,6 +106,34 @@ class AppHandler(object):
         from rattail.db import Session
         return Session(**kwargs)
 
+    def make_temp_dir(self, **kwargs):
+        """
+        Create a temporary directory.  This is mostly a convenience wrapper
+        around the built-in ``tempfile.mkdtemp()``.
+        """
+        if 'dir' not in kwargs:
+            workdir = self.config.workdir(require=False)
+            if workdir:
+                tmpdir = os.path.join(workdir, 'tmp')
+                if not os.path.exists(tmpdir):
+                    os.makedirs(tmpdir)
+                kwargs['dir'] = tmpdir
+        return tempfile.mkdtemp(**kwargs)
+
+    def make_temp_file(self, **kwargs):
+        """
+        Reserve a temporary filename.  This is mostly a convenience wrapper
+        around the built-in ``tempfile.mkstemp()``.
+        """
+        if 'dir' not in kwargs:
+            workdir = self.config.workdir(require=False)
+            if workdir:
+                tmpdir = os.path.join(workdir, 'tmp')
+                if not os.path.exists(tmpdir):
+                    os.makedirs(tmpdir)
+                kwargs['dir'] = tmpdir
+        return temp_path(**kwargs)
+
     def phone_number_is_invalid(self, number):
         """
         This method should validate the given phone number string, and if the
@@ -116,6 +153,26 @@ class AppHandler(object):
         except Exception as error:
             return six.text_type(error)
 
+    def render_currency(self, value, scale=2, **kwargs):
+        """
+        Must return a human-friendly display string for the given currency
+        value, e.g. ``Decimal('4.20')`` becomes ``"$4.20"``.
+        """
+        if value is not None:
+            if value < 0:
+                fmt = "(${{:0,.{}f}})".format(scale)
+                return fmt.format(0 - value)
+            fmt = "${{:0,.{}f}}".format(scale)
+            return fmt.format(value)
+
+    def render_datetime(self, value, **kwargs):
+        """
+        Must return a human-friendly display string for the given ``datetime``
+        object.
+        """
+        if value is not None:
+            return value.strftime('%Y-%m-%d %I:%M:%S %p')
+
 
 class GenericHandler(object):
     """
