@@ -104,6 +104,19 @@ class BatchHandler(object):
             return self.execute_with_versioning
         raise NotImplementedError("unknown batch action: {}".format(action))
 
+    def is_mutable(self, batch):
+        """
+        Returns a boolean indicating whether or not *any* modifications are to
+        be allowed for the given batch.  By default this returns ``False`` if
+        the batch is already executed, or has been marked complete; otherwise
+        returns ``True``.
+        """
+        if batch.executed:
+            return False
+        if batch.complete:
+            return False
+        return True
+
     def make_basic_batch(self, session, user=None, progress=None, **kwargs):
         """
         Make a new "basic" batch, with no customization beyond what is provided
@@ -723,6 +736,17 @@ class BatchHandler(object):
         """
         return False
 
+    def describe_execution(self, batch, **kwargs):
+        """
+        This method should essentially return some text describing briefly what
+        will happen when the given batch is executed.
+
+        :param batch: The batch in question, which is a candidate for
+           execution.
+
+        :returns: String value describing the batch execution.
+        """
+
     def do_execute(self, batch, user, progress=None, **kwargs):
         """
         Perform final execution for the batch.  What that means for any given
