@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -37,15 +37,19 @@ class VendorCatalogHandler(BatchHandler):
     """
     Handler for vendor catalog batches.
     """
-    batch_model_class = model.VendorCatalog
+    batch_model_class = model.VendorCatalogBatch
+
+    # make sure web app knows to employ versioning workarounds
+    # TODO: i am actually not sure why these *always* seem to be needed for
+    # this batch?  maybe the product relationships are too "tight" somehow?
+    populate_with_versioning = False
+    refresh_with_versioning = False
+    execute_with_versioning = False
 
     version_catchup_execute = [
         'ProductCost',
     ]
 
-    # TODO: change default for this, ultimately deprecate/remove
-    use_legacy_update_status = True
-
     def should_populate(self, batch):
         # all vendor catalogs must come from data file
         return True
@@ -117,6 +121,7 @@ class VendorCatalogHandler(BatchHandler):
             return
 
         row.upc = row.product.upc
+        row.item_id = row.product.item_id
         row.brand_name = row.product.brand.name if row.product.brand else None
         row.description = row.product.description
         row.size = row.product.size
@@ -148,34 +153,24 @@ class VendorCatalogHandler(BatchHandler):
                 row.unit_cost_diff_percent = row.unit_cost_diff / row.old_unit_cost
 
         # status
-        # TODO: deprecate/remove legacy status
-        if self.use_legacy_update_status:
-            diff = self.cost_differs(row, old_cost)
-            if diff:
-                row.status_code = row.STATUS_UPDATE_COST
-                row.status_text = diff
-            else:
-                row.status_code = row.STATUS_NO_CHANGE
-
+        if row.vendor_code != row.old_vendor_code:
+            row.status_code = row.STATUS_CHANGE_VENDOR_ITEM_CODE
+            row.status_text = "new vendor item code {} differs from old code {}".format(
+                repr(row.vendor_code), repr(row.old_vendor_code))
+        elif row.case_size != row.old_case_size:
+            row.status_code = row.STATUS_CHANGE_CASE_SIZE
+            row.status_text = "new case size {} differs from old case size {}".format(
+                repr(row.case_size), repr(row.old_case_size))
+        elif row.case_cost != row.old_case_cost:
+            row.status_code = row.STATUS_CHANGE_COST
+            row.status_text = "new case cost {} differs from old cost {}".format(
+                repr(row.case_cost), repr(row.old_case_cost))
+        elif row.unit_cost != row.old_unit_cost:
+            row.status_code = row.STATUS_CHANGE_COST
+            row.status_text = "new unit cost {} differs from old cost {}".format(
+                repr(row.unit_cost), repr(row.old_unit_cost))
         else:
-            if row.vendor_code != row.old_vendor_code:
-                row.status_code = row.STATUS_CHANGE_VENDOR_ITEM_CODE
-                row.status_text = "new vendor item code {} differs from old code {}".format(
-                    repr(row.vendor_code), repr(row.old_vendor_code))
-            elif row.case_size != row.old_case_size:
-                row.status_code = row.STATUS_CHANGE_CASE_SIZE
-                row.status_text = "new case size {} differs from old case size {}".format(
-                    repr(row.case_size), repr(row.old_case_size))
-            elif row.case_cost != row.old_case_cost:
-                row.status_code = row.STATUS_CHANGE_COST
-                row.status_text = "new case cost {} differs from old cost {}".format(
-                    repr(row.case_cost), repr(row.old_case_cost))
-            elif row.unit_cost != row.old_unit_cost:
-                row.status_code = row.STATUS_CHANGE_COST
-                row.status_text = "new unit cost {} differs from old cost {}".format(
-                    repr(row.unit_cost), repr(row.old_unit_cost))
-            else:
-                row.status_code = row.STATUS_NO_CHANGE
+            row.status_code = row.STATUS_NO_CHANGE
 
     def cost_differs(self, row, cost):
         """
