@@ -37,7 +37,7 @@ import logging
 import six
 
 from rattail.commands.core import Subcommand
-from rattail.config import parse_bool
+from rattail.config import parse_bool, parse_list
 
 
 log = logging.getLogger(__name__)
@@ -109,9 +109,15 @@ class Backup(Subcommand):
         parser.add_argument('--no-borg', action='store_true',
                             help="Do NOT create backup archive(s) via Borg.")
 
-        parser.add_argument('--borg_remotes', metavar='REMOTES',
+        parser.add_argument('--borg-remotes', metavar='REMOTES',
                             help="List of named \"remotes\" for Borg, where archives should be created.")
 
+        parser.add_argument('--borg-tag', metavar='TAG',
+                            help="Extra \"tag\" to embed within the name of the "
+                            "Borg archive which is created.  Note that an archive "
+                            "which is \"tagged\" in this way will never be pruned "
+                            "by this `rattail backup` command!")
+
         parser.add_argument('--dry-run', action='store_true',
                             help="Go through the motions as much as possible, to get an idea "
                             "of what the full backup would do, but don't actually do anything.")
@@ -191,10 +197,13 @@ class Backup(Subcommand):
 
             # we do *not* run borg by default, unless user or config file says to
             if args.borg or (not args.no_borg and self.config.getbool('rattail.backup', 'borg.enabled', usedb=False, default=False)):
-                remotes = args.borg_remotes or self.config.getlist('rattail.backup', 'borg.remotes', usedb=False)
+                remotes = (parse_list(args.borg_remotes) or
+                           self.config.getlist('rattail.backup', 'borg.remotes',
+                                               usedb=False))
                 self.make_borg_archives(remotes,
                                         include=args.included_prefixes,
                                         exclude=args.excluded_prefixes,
+                                        tag=args.borg_tag,
                                         dry_run=args.dry_run)
 
     def get_path_includes(self):
@@ -289,7 +298,8 @@ class Backup(Subcommand):
             if not dry_run:
                 subprocess.check_call(cmd)
 
-    def make_borg_archives(self, remotes, include=None, exclude=None, dry_run=False):
+    def make_borg_archives(self, remotes, include=None, exclude=None,
+                           tag=None, dry_run=False):
         borg = self.config.get('rattail.backup', 'borg', usedb=False)
         if not borg:
             borg = os.path.join(os.path.dirname(sys.executable), 'borg')
@@ -338,7 +348,15 @@ class Backup(Subcommand):
             for pattern in exclude:
                 cmd.extend(['--exclude', pattern])
 
-            cmd.append('::{}-{{now}}'.format(hostname))
+            if tag:
+                # note that in this case our hostname will be immediately
+                # followed by a colon instead of hyphen.  this is what "breaks"
+                # the typical pattern and ensures this tagged archive will not
+                # be pruned under typical command runs.
+                archive_name = '::{}:{}-{{now}}'.format(hostname, tag)
+            else:
+                archive_name = '::{}-{{now}}'.format(hostname)
+            cmd.append(archive_name)
 
             for prefix in prefixes:
                 cmd.append(prefix)
@@ -347,6 +365,11 @@ class Backup(Subcommand):
             if not dry_run:
                 subprocess.check_call(cmd, env=borg_env)
 
+            # the only thing left is to prune, which if we're tagging, we
+            # probably should just skip.  maybe let command line override?
+            if tag:
+                return
+
             # generate --keep args for prune, based on config
             keep = []
             keep_defaults = {
