@@ -569,12 +569,12 @@ class RattailConfig(object):
         spec = self.require('rattail.trainwreck', 'model', usedb=False)
         return import_module_path(spec)
 
-    def product_key(self):
+    def product_key(self, default='upc'):
         """
         Returns the name of the attribute which should be treated as the
         canonical product key field, e.g. 'upc' or 'item_id' etc.
         """
-        return self.get('rattail', 'product.key', default='upc')
+        return self.get('rattail', 'product.key', default=default) or default
 
     def product_key_title(self, key=None):
         """
