@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,8 +26,44 @@ DataSync Utilities
 
 from __future__ import unicode_literals, absolute_import
 
+import datetime
+
 from sqlalchemy import orm
 
+from rattail.db import api
+from rattail.time import localtime, make_utc
+
+
+def get_lastrun_setting(config, watcher_key):
+    """
+    Retrieve the "last run" setting name for the given watcher key.
+    """
+    return 'rattail.datasync.{}.watcher.lastrun'.format(watcher_key)
+
+
+def get_lastrun_timefmt(config):
+    """
+    Retrieve the "last run" time format.
+    """
+    return '%Y-%m-%d %H:%M:%S'
+
+
+def get_lastrun(config, watcher_key, local=False, tzinfo=True, session=None):
+    """
+    Retrieve the "last run" time for the datasync watcher thread identifed by
+    ``watcher_key``.
+    """
+    # the 'last run' value is maintained as UTC
+    lastrun_setting = get_lastrun_setting(config, watcher_key)
+    timefmt = get_lastrun_timefmt(config)
+    lastrun = api.get_setting(session, lastrun_setting)
+    if lastrun:
+        lastrun = datetime.datetime.strptime(lastrun, timefmt)
+        if local:
+            return localtime(config, lastrun, from_utc=True, tzinfo=tzinfo)
+        else:
+            return make_utc(lastrun, tzinfo=tzinfo)
+
 
 def make_dependency_sorter(model):
     """
@@ -80,3 +116,12 @@ def make_dependency_sorter(model):
         return 0
 
     return dependency_sorter
+
+
+def next_batch_id(session):
+    """
+    Return the next "batch ID" for datasync changes, for use when recording by
+    a watcher thread.
+    """
+    sql = "select nextval('datasync_change_batch_id_seq')"
+    return session.execute(sql).scalar()
