@@ -45,7 +45,7 @@ if sqlalchemy:
         related to the SQLAlchemy-Continuum integration.
         """
 
-        def __init__(self, rattail_config=None, rattail_record_changes=False, continuum_user=None, **kwargs):
+        def __init__(self, rattail_config=None, rattail_record_changes=None, continuum_user=None, **kwargs):
             """
             Custom constructor, to allow specifying the Continuum user at session
             creation.  If ``continuum_user`` is specified, its value will be passed
@@ -55,7 +55,9 @@ if sqlalchemy:
             self.rattail_config = rattail_config
 
             # maybe record changes
-            if rattail_record_changes or getattr(self.bind, 'rattail_record_changes', False):
+            if rattail_record_changes is None:
+                rattail_record_changes = getattr(self.bind, 'rattail_record_changes', False)
+            if rattail_record_changes:
                 from rattail.db.changes import record_changes
                 record_changes(self, config=self.rattail_config)
             else:
@@ -87,7 +89,7 @@ if sqlalchemy:
             self.continuum_user = user
 
 
-    Session = orm.sessionmaker(class_=SessionBase, rattail_config=None, rattail_record_changes=False, expire_on_commit=False)
+    Session = orm.sessionmaker(class_=SessionBase, rattail_config=None, expire_on_commit=False)
 
 
 else: # no sqlalchemy
