@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2019 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,6 +28,8 @@ from __future__ import unicode_literals, absolute_import
 
 import logging
 
+from packaging.version import parse as parse_version
+import sqlalchemy as sa
 from sqlalchemy.orm import object_mapper, RelationshipProperty
 from sqlalchemy.orm.interfaces import SessionExtension
 from sqlalchemy.orm.session import Session
@@ -98,6 +100,14 @@ class ChangeRecorder(object):
         model.DataSyncChange,
     )
 
+    # once upon a time we supposedly needed to specify `passive=True` when
+    # invoking `session.is_modified()` but that has apparently been deprecated
+    # for some time now.  we likely should just require SA>=0.8 instead of
+    # maintaining this logic?
+    is_modified_kw = {}
+    if parse_version(sa.__version__) < parse_version('0.8'):
+        is_modified_kw['passive'] = True
+
     def __call__(self, session, flush_context, instances):
         """
         Method invoked when session ``before_flush`` event occurs.
@@ -116,7 +126,7 @@ class ChangeRecorder(object):
             if not self.ignore_object(obj):
                 self.process_new_object(session, obj)
         for obj in session.dirty:
-            if not self.ignore_object(obj) and session.is_modified(obj, passive=True):
+            if not self.ignore_object(obj) and session.is_modified(obj, **self.is_modified_kw):
                 # Orphaned objects which really are pending deletion show up in
                 # session.dirty instead of session.deleted, hence this check.
                 # https://groups.google.com/d/msg/sqlalchemy/H4nQTHphc0M/Xr8-Cgra0Z4J
@@ -129,7 +139,20 @@ class ChangeRecorder(object):
         """
         Return ``True`` if changes for the given object should be ignored.
         """
-        return isinstance(obj, self.ignored_classes)
+        # ignore certain classes per declaration
+        if isinstance(obj, self.ignored_classes):
+            return True
+
+        # TODO: is there a smarter way to check?
+        # definitely don't care about changes to any version tables
+        if obj.__class__.__name__.endswith('Version'):
+            return True
+
+        # ignore LabelProfile objects which are *not* marked "sync me"
+        if isinstance(obj, model.LabelProfile) and not obj.sync_me:
+            return True
+
+        return False # i.e. don't ignore
 
     def process_new_object(self, session, obj):
         """
@@ -147,11 +170,20 @@ class ChangeRecorder(object):
         """
         Record changes as appropriate, for the given 'deleted' object.
         """
-        # TODO: Is this hacky?  Seems like maybe so...
+        # TODO: should perhaps find a "cleaner" way to handle these..?
+
+        # mark Person as dirty, when contact info is removed
         if isinstance(obj, (model.PersonEmailAddress, model.PersonPhoneNumber, model.PersonMailingAddress)):
             self.record_rattail_change(session, obj.person, type_='dirty')
+
+        # mark Employee as dirty, when department info is removed
         if isinstance(obj, (model.EmployeeStore, model.EmployeeDepartment)):
             self.record_rattail_change(session, obj.employee, type_='dirty')
+
+        # mark Product as dirty, when cost info is removed
+        if isinstance(obj, model.ProductCost):
+            self.record_rattail_change(session, obj.product, type_='dirty')
+
         self.record_rattail_change(session, obj, type_='deleted')
 
     def is_deletable_orphan(self, instance):
@@ -203,6 +235,10 @@ class ChangeRecorder(object):
         if isinstance(instance, (model.BatchMixin, model.BatchRowMixin)):
             return False
 
+        # no need to record changes for email attempts
+        if isinstance(instance, model.EmailAttempt):
+            return False
+
         # Ignore instances which don't use UUID.
         if not hasattr(instance, 'uuid'):
             return False
