@@ -74,5 +74,9 @@ from .batch.pricing import PricingBatch, PricingBatchRow
 from .batch.product import ProductBatch, ProductBatchRow
 from .batch.purchase import PurchaseBatch, PurchaseBatchRow, PurchaseBatchRowClaim, PurchaseBatchCredit
 from .batch.custorder import CustomerOrderBatch, CustomerOrderBatchRow
-from .batch.vendorcatalog import VendorCatalog, VendorCatalogRow
-from .batch.vendorinvoice import VendorInvoice, VendorInvoiceRow
+from .batch.vendorcatalog import (VendorCatalogBatch, VendorCatalogBatchRow,
+                                  # TODO: deprecate / remove these
+                                  VendorCatalog, VendorCatalogRow)
+from .batch.vendorinvoice import (VendorInvoiceBatch, VendorInvoiceBatchRow,
+                                  # TODO: deprecate / remove these
+                                  VendorInvoice, VendorInvoiceRow)
