@@ -42,7 +42,7 @@ class PurchaseBatch(BatchMixin, PurchaseBase, Base):
     Hopefully generic batch used for entering new purchases into the system, etc.?
     """
     batch_key = 'purchase'
-    __tablename__ = 'purchase_batch'
+    __tablename__ = 'batch_purchase'
     __batchrow_class__ = 'PurchaseBatchRow'
     model_title = "Purchasing Batch"
     model_title_plural = "Purchasing Batches"
@@ -50,8 +50,10 @@ class PurchaseBatch(BatchMixin, PurchaseBase, Base):
     @declared_attr
     def __table_args__(cls):
         return cls.__batch_table_args__() + cls.__purchase_table_args__() + (
-            sa.ForeignKeyConstraint(['purchase_uuid'], ['purchase.uuid'], name='purchase_batch_fk_purchase'),
-            sa.ForeignKeyConstraint(['truck_dump_batch_uuid'], ['purchase_batch.uuid'], name='purchase_batch_fk_truck_dump_batch', use_alter=True),
+            sa.ForeignKeyConstraint(['purchase_uuid'], ['purchase.uuid'],
+                                    name='batch_purchase_fk_purchase'),
+            sa.ForeignKeyConstraint(['truck_dump_batch_uuid'], ['batch_purchase.uuid'],
+                                    name='batch_purchase_fk_truck_dump_batch', use_alter=True),
         )
 
     STATUS_OK                   = 1
@@ -192,13 +194,14 @@ class PurchaseBatchRow(BatchRowMixin, PurchaseItemBase, Base):
     """
     Row of data within a purchase batch.
     """
-    __tablename__ = 'purchase_batch_row'
+    __tablename__ = 'batch_purchase_row'
     __batch_class__ = PurchaseBatch
 
     @declared_attr
     def __table_args__(cls):
         return cls.__batchrow_table_args__() + cls.__purchaseitem_table_args__() + (
-            sa.ForeignKeyConstraint(['item_uuid'], ['purchase_item.uuid'], name='purchase_batch_row_fk_item'),
+            sa.ForeignKeyConstraint(['item_uuid'], ['purchase_item.uuid'],
+                                    name='batch_purchase_row_fk_item'),
         )
 
     STATUS_OK                           = 1
@@ -278,10 +281,12 @@ class PurchaseBatchRowClaim(Base):
     corresponding "child" batch row which claims it, as well as the claimed
     quantities etc.
     """
-    __tablename__ = 'purchase_batch_row_claim'
+    __tablename__ = 'batch_purchase_row_claim'
     __table_args__ = (
-        sa.ForeignKeyConstraint(['claiming_row_uuid'], ['purchase_batch_row.uuid'], name='purchase_batch_row_claim_fk_claiming_row'),
-        sa.ForeignKeyConstraint(['claimed_row_uuid'], ['purchase_batch_row.uuid'], name='purchase_batch_row_claim_fk_claimed_row'),
+        sa.ForeignKeyConstraint(['claiming_row_uuid'], ['batch_purchase_row.uuid'],
+                                name='batch_purchase_row_claim_fk_claiming_row'),
+        sa.ForeignKeyConstraint(['claimed_row_uuid'], ['batch_purchase_row.uuid'],
+                                name='batch_purchase_row_claim_fk_claimed_row'),
     )
 
     uuid = uuid_column()
@@ -369,12 +374,13 @@ class PurchaseBatchCredit(PurchaseCreditBase, Base):
     """
     Represents a working copy of purchase credit tied to a batch row.
     """
-    __tablename__ = 'purchase_batch_credit'
+    __tablename__ = 'batch_purchase_credit'
 
     @declared_attr
     def __table_args__(cls):
         return cls.__purchasecredit_table_args__() + (
-            sa.ForeignKeyConstraint(['row_uuid'], ['purchase_batch_row.uuid'], name='purchase_batch_credit_fk_row'),
+            sa.ForeignKeyConstraint(['row_uuid'], ['batch_purchase_row.uuid'],
+                                    name='batch_purchase_credit_fk_row'),
         )
 
     uuid = uuid_column()
