@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -34,19 +34,22 @@ from rattail.db.model import Base, Vendor, FileBatchMixin, ProductBatchRowMixin
 from rattail.db.types import GPCType
 
 
-class VendorCatalog(FileBatchMixin, Base):
+class VendorCatalogBatch(FileBatchMixin, Base):
     """
-    Vendor catalog, the source data file of which has been provided by a user,
-    and may be further processed in some site-specific way.
+    Vendor catalog batch, the source data file of which has been provided by a
+    user, and may be further processed in some site-specific way.
     """
-    __tablename__ = 'vendor_catalog'
-    __batchrow_class__ = 'VendorCatalogRow'
+    __tablename__ = 'batch_vendorcatalog'
+    __batchrow_class__ = 'VendorCatalogBatchRow'
+    model_title = "Vendor Catalog Batch"
+    model_title_plural = "Vendor Catalog Batches"
+    batch_key = 'vendor_catalog'
 
     @declared_attr
     def __table_args__(cls):
         return cls.__default_table_args__() + (
             sa.ForeignKeyConstraint(['vendor_uuid'], ['vendor.uuid'],
-                                    name='vendor_catalog_fk_vendor'),
+                                    name='batch_vendorcatalog_fk_vendor'),
             )
 
     parser_key = sa.Column(sa.String(length=100), nullable=False, doc="""
@@ -70,19 +73,22 @@ class VendorCatalog(FileBatchMixin, Base):
     effective dates on a per-product basis.
     """)
 
+# TODO: deprecate / remove this
+VendorCatalog = VendorCatalogBatch
 
-class VendorCatalogRow(ProductBatchRowMixin, Base):
+
+class VendorCatalogBatchRow(ProductBatchRowMixin, Base):
     """
-    Row of data within a vendor catalog.
+    Row of data within a vendor catalog batch.
     """
-    __tablename__ = 'vendor_catalog_row'
-    __batch_class__ = VendorCatalog
+    __tablename__ = 'batch_vendorcatalog_row'
+    __batch_class__ = VendorCatalogBatch
 
     @declared_attr
     def __table_args__(cls):
         return cls.__default_table_args__() + (
             sa.ForeignKeyConstraint(['cost_uuid'], ['product_cost.uuid'],
-                                    name='vendor_catalog_row_fk_cost'),
+                                    name='batch_vendorcatalog_row_fk_cost'),
         )
 
     STATUS_NO_CHANGE = 1
@@ -110,7 +116,7 @@ class VendorCatalogRow(ProductBatchRowMixin, Base):
         associated, if any.
         """,
         backref=orm.backref(
-            '_vendor_catalog_rows', doc="""
+            '_vendor_catalog_batch_rows', doc="""
             List of vendor catalog batch rows which associate directly with
             this cost record.
             """))
@@ -205,3 +211,6 @@ class VendorCatalogRow(ProductBatchRowMixin, Base):
     Percentage amount of the "allowance" (temporary discount) for the cost, if
     applicable.
     """)
+
+# TODO: deprecate / remove this
+VendorCatalogRow = VendorCatalogBatchRow
