@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -42,8 +42,32 @@ class Department(Base):
     __versioned__ = {}
 
     uuid = uuid_column()
-    number = sa.Column(sa.Integer())
-    name = sa.Column(sa.String(length=30))
+
+    number = sa.Column(sa.Integer(), nullable=True, doc="""
+    Presumably unique number for the department, as integer.
+    """)
+
+    name = sa.Column(sa.String(length=30), nullable=True, doc="""
+    Name for the department.
+    """)
+
+    product = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Flag indicating whether the department may be used for product
+    organization, irrespective of its :attr:`personnel` flag.
+    """)
+
+    personnel = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Flag indicating whether the department may be used for personnel
+    organization, irrespective of its :attr:`product` flag.
+    """)
+
+    exempt_from_gross_sales = sa.Column(sa.Boolean(), nullable=True, doc="""
+    Flag indicating whether items in this department should (not) contribute to
+    gross sales figures.  The SIL book says this about it:
+
+       Dollar sales are not to be included in gross sales. (i.e., Postage
+       Stamps, Lottery Tickets, etc.).
+    """)
 
     def __str__(self):
         return self.name or ''
@@ -88,12 +112,25 @@ class Category(Base):
     __versioned__ = {}
 
     uuid = uuid_column()
-    number = sa.Column(sa.Integer())
-    code = sa.Column(sa.String(length=8), nullable=True)
-    name = sa.Column(sa.String(length=50))
-    department_uuid = sa.Column(sa.String(length=32))
 
-    department = orm.relationship(Department)
+    code = sa.Column(sa.String(length=20), nullable=True, doc="""
+    Unique code for the category, as string.
+    """)
+
+    number = sa.Column(sa.Integer(), nullable=True, doc="""
+    Number for the category.  NOTE: Most code leverages the :attr:`code`
+    instead of this number, which is essentially ignored.
+    """)
+
+    name = sa.Column(sa.String(length=50), nullable=True, doc="""
+    Descriptive name for the category.
+    """)
+
+    department_uuid = sa.Column(sa.String(length=32))
+    department = orm.relationship(Department, doc="""
+    Reference to the :class:`Department` to which this category belongs, if
+    applicable.
+    """)
 
     def __str__(self):
         return self.name or ''
