@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -47,6 +47,43 @@ from rattail.util import pretty_quantity
 log = logging.getLogger(__name__)
 
 
+@six.python_2_unicode_compatible
+class UnitOfMeasure(Base):
+    """
+    Maps a UOM abbreviation used by the organization, to the proper UOM code
+    used internally by Rattail.
+
+    Note that the SIL code is similar, but apparently different, from the
+    `codes defined by GS1`_.
+
+    .. _codes defined by GS1: https://resources.gs1us.org/GS1-US-Data-Hub-Help-Center/ArtMID/3451/ArticleID/116/Unit-of-Measure-Codes
+    """
+    __tablename__ = 'unit_of_measure'
+    __table_args__ = (
+        sa.UniqueConstraint('abbreviation', name='unit_of_measure_uq_abbreviation'),
+    )
+    __versioned__ = {}
+    model_title = "Unit of Measure"
+    model_title_plural = "Units of Measure"
+
+    uuid = uuid_column()
+
+    abbreviation = sa.Column(sa.String(length=20), nullable=False, doc="""
+    UOM abbreviation as it is used by the organization, e.g. 'OZ'.
+    """)
+
+    sil_code = sa.Column(sa.String(length=4), nullable=True, doc="""
+    SIL code for the UOM, as used internally by Rattail, e.g. '48'.
+    """)
+
+    notes = sa.Column(sa.Text(), nullable=True, doc="""
+    Misc. notes for this mapping.
+    """)
+
+    def __str__(self):
+        return self.abbreviation or ""
+
+
 @six.python_2_unicode_compatible
 class Brand(Base):
     """
