@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -54,7 +54,8 @@ class PurchaseBase(object):
             sa.ForeignKeyConstraint(['store_uuid'], ['store.uuid'], name='{}_fk_store'.format(cls.__tablename__)),
             sa.ForeignKeyConstraint(['vendor_uuid'], ['vendor.uuid'], name='{}_fk_vendor'.format(cls.__tablename__)),
             sa.ForeignKeyConstraint(['department_uuid'], ['department.uuid'], name='{}_fk_department'.format(cls.__tablename__)),
-            sa.ForeignKeyConstraint(['buyer_uuid'], ['employee.uuid'], name='{}_purchase_fk_buyer'.format(cls.__tablename__)),
+            sa.ForeignKeyConstraint(['buyer_uuid'], ['employee.uuid'],
+                                    name='{}_fk_buyer'.format(cls.__tablename__)),
         )
 
     store_uuid = sa.Column(sa.String(length=32), nullable=False)
@@ -508,6 +509,11 @@ class Purchase(PurchaseBase, Base):
 
     uuid = uuid_column()
 
+    id = sa.Column(sa.Integer(), sa.Sequence('batch_id_seq'), nullable=True, doc="""
+    Numeric ID for the purchase.  This is auto-increment from the general Batch
+    ID sequence.
+    """)
+
     status = sa.Column(sa.Integer(), nullable=False, doc="""
     Numeric code used to signify current status for the purchase, e.g. placed
     or paid etc.
@@ -528,6 +534,12 @@ class Purchase(PurchaseBase, Base):
         this system.
         """)
 
+    @property
+    def id_str(self):
+        if self.id:
+            return "{:08d}".format(self.id)
+        return ""
+
 
 class PurchaseItem(PurchaseItemBase, Base):
     """
