@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,6 +26,7 @@ Data Models for Stores
 
 from __future__ import unicode_literals, absolute_import
 
+import six
 import sqlalchemy as sa
 from sqlalchemy.orm import relationship
 from sqlalchemy.ext.orderinglist import ordering_list
@@ -34,6 +35,7 @@ from .core import Base, uuid_column
 from .contact import PhoneNumber, EmailAddress
 
 
+@six.python_2_unicode_compatible
 class Store(Base):
     """
     Represents a store (physical or otherwise) within the organization.
@@ -46,8 +48,8 @@ class Store(Base):
     name = sa.Column(sa.String(length=100))
     database_key = sa.Column(sa.String(length=30))
 
-    def __unicode__(self):
-        return unicode(self.name or '')
+    def __str__(self):
+        return str(self.name or '')
 
     def add_email_address(self, address, type='Info'):
         email = StoreEmailAddress(address=address, type=type)
