@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -32,10 +32,6 @@ import logging
 
 from sqlalchemy import orm
 
-import formencode as fe
-from formencode.validators import Email
-from formencode.national import USPhoneNumber
-
 # TODO: Deprecate/remove these imports.
 from rattail.db.config import engine_from_config, get_engines, get_default_engine, configure_session
 
@@ -68,10 +64,11 @@ class short_session(object):
     Context manager for a short-lived database session
     """
 
-    def __init__(self, session=None, Session=None):
+    def __init__(self, session=None, Session=None, commit=False):
         self.session = session
         self.Session = Session
         self.private_session = not bool(session)
+        self.commit = commit
 
     def __enter__(self):
         if not self.session:
@@ -83,6 +80,8 @@ class short_session(object):
 
     def __exit__(self, exc_type, exc_value, traceback):
         if self.private_session:
+            if self.commit:
+                self.session.commit()
             self.session.close()
             self.session = None
 
@@ -110,12 +109,15 @@ def make_topo_sortkey(model, metadata=None):
     for i, table in enumerate(metadata.sorted_tables, 1):
         tables[table.name] = i
 
-    log.debug("topo sortkeys for '{}' will be:\n{}".format(model.__name__, pprint.pformat(
-        [(i, name) for name, i in sorted(tables.iteritems(), key=lambda t: t[1])])))
+    # log.debug("topo sortkeys for '{}' will be:\n{}".format(model.__name__, pprint.pformat(
+    #     [(i, name) for name, i in sorted(tables.items(), key=lambda t: t[1])])))
 
     def sortkey(name):
-        mapper = orm.class_mapper(getattr(model, name))
-        return tuple(tables[t.name] for t in mapper.tables)
+        if hasattr(model, name):
+            mapper = orm.class_mapper(getattr(model, name))
+            return tuple(tables[t.name] for t in mapper.tables)
+        else:
+            return tuple()
 
     return sortkey
 
@@ -148,41 +150,6 @@ def normalize_full_name(first_name, last_name):
     return ''
 
 
-##############################
-# email address validation
-##############################
-
-class EmailValidator(object):
-    """
-    Simple validator, used to ensure an email address matches the general
-    expected pattern.
-
-    This leverages the FormEncode library for general address validation.  It
-    can optionally use DNS lookups to confirm if the domain portion of the
-    email address is valid.
-    """
-
-    def __init__(self, resolve_domain=False, error=False):
-        self.validator = Email(resolve_domain=resolve_domain)
-        self.error = error
-
-    def validate(self, address):
-        if address:
-            try:
-                return self.validator.to_python(address)
-            except fe.Invalid:
-                if self.error:
-                    raise
-
-
-def validate_email_address(address, resolve_domain=False, error=False):
-    """
-    Validate a single email address.
-    """
-    validator = EmailValidator(resolve_domain=resolve_domain, error=error)
-    return validator.validate(address)
-
-
 ##############################
 # phone number validation
 ##############################
@@ -192,18 +159,17 @@ class PhoneValidator(object):
     Simple validator, used to ensure a phone number matches the general
     expected pattern.
     """
+    # NOTE: this was stolen from FormEncode
+    _phoneRE = re.compile(r'^\s*(?:1-)?(\d\d\d)[\- \.]?(\d\d\d)[\- \.]?(\d\d\d\d)(?:\s*ext\.?\s*(\d+))?\s*$', re.I)
 
     def __init__(self, error=False):
-        self.validator = USPhoneNumber()
         self.error = error
 
     def validate(self, number):
         if number:
-            try:
-                return self.validator.to_python(number)
-            except fe.Invalid:
-                if self.error:
-                    raise
+            if not self._phoneRE.search(number):
+                raise ValueError("Phone number is not valid")
+            return number
 
 
 def validate_phone_number(number, error=False):
