@@ -81,6 +81,24 @@ CUSTORDER_BATCH_MODE = {
 }
 
 
+CUSTORDER_STATUS_ORDERED                = 10
+# CUSTORDER_STATUS_PAID                   = 20
+
+CUSTORDER_STATUS = {
+    CUSTORDER_STATUS_ORDERED            : "ordered",
+    # CUSTORDER_STATUS_PAID               : "paid",
+}
+
+
+CUSTORDER_ITEM_STATUS_ORDERED           = 10
+# CUSTORDER_ITEM_STATUS_PAID              = 20
+
+CUSTORDER_ITEM_STATUS = {
+    CUSTORDER_ITEM_STATUS_ORDERED       : "ordered",
+    # CUSTORDER_ITEM_STATUS_PAID          : "paid",
+}
+
+
 EMAIL_ATTEMPT_CREATED           = 0
 EMAIL_ATTEMPT_SUCCESS           = 1
 EMAIL_ATTEMPT_FAILURE           = 2
