@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,6 +28,8 @@ This module contains all core Rattail exception classes.
 
 from __future__ import unicode_literals, absolute_import
 
+import six
+
 
 class RattailError(Exception):
     """
@@ -41,6 +43,7 @@ class ConfigurationError(RattailError):
     """
 
 
+@six.python_2_unicode_compatible
 class SQLAlchemyNotInstalled(RattailError):
     """
     Error raised when an operation is requested which requires SQLAlchemy
@@ -49,24 +52,26 @@ class SQLAlchemyNotInstalled(RattailError):
     def __init__(self, error):
         self.error = error
 
-    def __unicode__(self):
+    def __str__(self):
         return ("Hm, looks like SQLAlchemy may not be installed?  "
                 "(Perhaps you should do: 'pip install rattail[db]'?)  "
-                "Original error was: {0}".format(self.error))
+                "Original error was: {}".format(self.error))
 
 
+@six.python_2_unicode_compatible
 class WindowsExtensionsNotInstalled(RattailError):
     """
     Error raised when an operation is requested which requires the "Python for
     Windows Extensions" to be instealled, but it is not available.
     """
 
-    def __unicode__(self):
+    def __str__(self):
         return ("Cannot proceed because Python for Windows Extensions is not installed.  Please see "
                 "https://rattailproject.org/moin/Installation/Windows/Python#Python_for_Windows_Extensions "
                 "for more info.")
 
 
+@six.python_2_unicode_compatible
 class MailTemplateNotFound(ConfigurationError):
 
     def __init__(self, key):
@@ -78,26 +83,24 @@ class MailTemplateNotFound(ConfigurationError):
                 "configured template folders.".format(self.key))
 
 
+@six.python_2_unicode_compatible
 class SenderNotFound(ConfigurationError):
 
     def __init__(self, key):
         self.key = key
 
-    def __unicode__(self):
-        return ("No email sender (From: address) found in config.  Please set '{0}.from' "
+    def __str__(self):
+        return ("No email sender (From: address) found in config.  Please set '{}.from' "
                 "(or 'default.from') in the [rattail.mail] section.".format(self.key))
 
 
+@six.python_2_unicode_compatible
 class RecipientsNotFound(ConfigurationError):
     
     def __init__(self, key):
         self.key = key
 
     def __str__(self):
-        return (b"No recipients found in config for '{0}' emails.  Please set '{0}.to' "
-                "(or 'default.to') in the [rattail.mail] section.".format(self.key))
-
-    def __unicode__(self):
         return ("No recipients found in config for '{0}' emails.  Please set '{0}.to' "
                 "(or 'default.to') in the [rattail.mail] section.".format(self.key))
 
@@ -108,6 +111,7 @@ class FileOperationError(RattailError):
     """
 
 
+@six.python_2_unicode_compatible
 class PathNotFound(FileOperationError):
     """
     Raised when "path not found" errors are encountered within the
@@ -119,8 +123,8 @@ class PathNotFound(FileOperationError):
     def __init__(self, original_error):
         self.original_error = original_error
 
-    def __unicode__(self):
-        return '{0}: {1}'.format(
+    def __str__(self):
+        return '{}: {}'.format(
             self.original_error.__class__.__name__,
             self.original_error)
 
@@ -136,28 +140,32 @@ class PalmError(RattailError):
     """
 
 
+@six.python_2_unicode_compatible
 class PalmClassicDatabaseTypelibNotFound(PalmError):
 
-    def __unicode__(self):
+    def __str__(self):
         return ("The Python module for the Palm Classic Database type library "
                 "could not be generated.  (Is the HotSync Manager software "
                 "installed?)")
 
 
+@six.python_2_unicode_compatible
 class PalmConduitManagerNotFound(PalmError):
 
-    def __unicode__(self):
+    def __str__(self):
         return ("The Palm Desktop Conduit Manager could not be instantiated.  "
                 "(Is the HotSync Manager software installed?)")
 
 
+@six.python_2_unicode_compatible
 class PalmConduitAlreadyRegistered(PalmError):
 
-    def __unicode__(self):
+    def __str__(self):
         return "The Rattail Palm conduit is already registered."
 
 
+@six.python_2_unicode_compatible
 class PalmConduitNotRegistered(PalmError):
 
-    def __unicode__(self):
+    def __str__(self):
         return "The Rattail Palm conduit is not registered."
