@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -29,11 +29,13 @@ from __future__ import unicode_literals, absolute_import
 import os
 import sys
 import time
-import Queue
+from six.moves import queue
 import socket
+import subprocess
 import logging
 from traceback import format_exception
 
+from rattail.config import parse_bool, parse_list
 from rattail.mail import send_email
 
 
@@ -57,6 +59,39 @@ class Action(object):
         raise NotImplementedError
 
 
+class CommandAction(Action):
+    """
+    Simple file monitor action which can execute a command as a subprocess.
+    """
+
+    def __init__(self, config, cmd):
+        self.config = config
+        self.cmd = cmd
+
+    def __call__(self, path, **kwargs):
+        """
+        Run the requested command.
+        """
+        filename = os.path.basename(path)
+        # TODO: this really should default to False instead
+        shell = parse_bool(kwargs.pop('shell', True))
+
+        if shell:
+            # TODO: probably shoudn't use format() b/c who knows what is in
+            # that command line, that might trigger errors
+            cmd = self.cmd.format(path=path, filename=filename)
+
+        else:
+            cmd = []
+            for term in parse_list(self.cmd):
+                term = term.replace('{path}', path)
+                term = term.replace('{filename}', filename)
+                cmd.append(term)
+
+        log.debug("final command to run is: %s", cmd)
+        subprocess.check_call(cmd, shell=shell)
+
+
 class StopProcessing(Exception):
     """
     Simple exception to indicate action processing should stop.  This is really
@@ -89,7 +124,7 @@ def perform_actions(profile):
 
         try:
             path = profile.queue.get_nowait()
-        except Queue.Empty:
+        except queue.Empty:
             pass
         except StopProcessing:
             stop = True
