@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2019 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,16 +24,18 @@
 File Monitor Configuration
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import os
 import re
+import getpass
 import warnings
 import logging
 
 from rattail.config import parse_list
 from rattail.util import load_object
 from rattail.exceptions import ConfigurationError
+from rattail.filemon.actions import CommandAction
 
 
 log = logging.getLogger(__name__)
@@ -173,18 +175,19 @@ class Profile(object):
             self.actions.append(self._config_action(action))
 
     def _config_action(self, name):
-        function = self._config_string(u'action.{0}.func'.format(name))
-        class_ = self._config_string(u'action.{0}.class'.format(name))
+        """
+        Retrieve an "action" value from config, for the current profile.  This
+        returns a :class:`ProfileAction` instance.
+        """
+        function = self._config_string('action.{}.func'.format(name))
+        class_ = self._config_string('action.{}.class'.format(name))
+        cmd = self._config_string('action.{}.cmd'.format(name))
 
-        if function and class_:
+        specs = [1 if spec else 0 for spec in (function, class_, cmd)]
+        if sum(specs) != 1:
             raise ConfigurationError(
-                u"File monitor profile '{0}' has both function *and* class defined for "
-                u"action '{1}' (must have one or the other).".format(self.key, name))
-
-        if not function and not class_:
-            raise ConfigurationError(
-                u"File monitor profile '{0}' has neither function *nor* class defined for "
-                u"action '{1}' (must have one or the other).".format(self.key, name))
+                "File monitor profile '{}' (action '{}') must have exactly one of: "
+                "function, class, command".format(self.key, name))
 
         action = ProfileAction()
         action.config = self.config
@@ -192,21 +195,29 @@ class Profile(object):
         if function:
             action.spec = function
             action.action = load_object(action.spec)
-        else:
+        elif class_:
             action.spec = class_
             action.action = load_object(action.spec)(self.config)
+        elif cmd:
+            action.spec = cmd
+            action.action = CommandAction(self.config, cmd)
 
-        action.args = self._config_list(u'action.{0}.args'.format(name))
+        action.args = self._config_list('action.{}.args'.format(name))
 
         action.kwargs = {}
-        pattern = re.compile(ur'^{0}\.action\.{1}\.kwarg\.(?P<keyword>\w+)$'.format(self.key, name), re.IGNORECASE)
-        for option in self.config.options(u'rattail.filemon'):
+        pattern = re.compile(r'^{}\.action\.{}\.kwarg\.(?P<keyword>\w+)$'.format(self.key, name), re.IGNORECASE)
+
+        # TODO: this should not be referencing the config parser directly!
+        # (but we have no other way yet, to know which options are defined)
+        # (we should at least allow config to be defined in DB Settings)
+        # (however that should be optional, since some may not have a DB)
+        for option in self.config.parser.options('rattail.filemon'):
             match = pattern.match(option)
             if match:
-                action.kwargs[match.group(u'keyword')] = self.config.get(u'rattail.filemon', option)
+                action.kwargs[match.group('keyword')] = self.config.get('rattail.filemon', option)
 
-        action.retry_attempts = self._config_int(u'action.{0}.retry_attempts'.format(name), minimum=1)
-        action.retry_delay = self._config_int(u'action.{0}.retry_delay'.format(name), minimum=0)
+        action.retry_attempts = self._config_int('action.{}.retry_attempts'.format(name), minimum=1)
+        action.retry_delay = self._config_int('action.{}.retry_delay'.format(name), minimum=0)
         return action
 
     def _config_boolean(self, option, default=None):
@@ -214,14 +225,16 @@ class Profile(object):
                                    default=default)
 
     def _config_int(self, option, minimum=0):
-        option = u'{0}.{1}'.format(self.key, option)
-        if self.config.has_option(u'rattail.filemon', option):
-            value = self.config.getint(u'rattail.filemon', option)
-            if value < minimum:
-                log.warning(u"config value {0} is too small; falling back to minimum "
-                            u"of {1} for option: {2}".format(value, minimum, option))
-                value = minimum
-        else:
+        """
+        Retrieve an integer value from config, for the current profile.
+        """
+        option = '{}.{}'.format(self.key, option)
+        value = self.config.getint('rattail.filemon', option)
+        if value is None:
+            value = minimum
+        elif value < minimum:
+            log.warning("config value {} is too small; falling back to minimum "
+                        "of {} for option: {}".format(value, minimum, option))
             value = minimum
         return value
 
@@ -237,11 +250,13 @@ class Profile(object):
         and prunes those which do not exist or do not refer to directories.
         """
         normalized = []
+        user = getpass.getuser()
         for path in dirs:
             path = os.path.abspath(path)
             if not os.path.exists(path):
-                log.warning(u"pruning folder which does not exist for profile "
-                            u"{0}: {1}".format(repr(self.key), repr(path)))
+                log.warning("pruning folder which does not exist (or perhaps is "
+                            "just not visible? check perms for '%s' user!) for "
+                            "profile '%s': %s", user, self.key, path)
                 continue
             if not os.path.isdir(path):
                 log.warning(u"pruning folder which is not a directory for profile "
@@ -352,7 +367,7 @@ def load_legacy_profiles(config):
         log.debug(u"loading profile: {0}".format(key))
         monitored[key] = LegacyProfile(config, key)
 
-    for key in monitored.keys():
+    for key in list(monitored):
         profile = monitored[key]
 
         # Prune any profiles with no valid folders to monitor.
