@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,9 +26,12 @@ Global Product Code
 
 from __future__ import unicode_literals, absolute_import
 
+import six
+
 from rattail import barcodes
 
 
+@six.python_2_unicode_compatible
 class GPC(object):
     """
     Class to abstract the details of Global Product Code data.  Examples of
@@ -55,10 +58,14 @@ class GPC(object):
         ``calc_check_digit`` value of ``True`` will be perceived as equivalent
         to ``'upc'``.
         """
+        value = six.text_type(value)
+
+        if calc_check_digit == 'auto':
+            calc_check_digit = 'upc' if len(value) < 12 else False
 
-        value = str(value)
         if calc_check_digit is True or calc_check_digit == 'upc':
-            value += str(barcodes.upc_check_digit(value))
+            value += six.text_type(barcodes.upc_check_digit(value))
+
         self.value = int(value)
 
     def __eq__(self, other):
@@ -73,6 +80,10 @@ class GPC(object):
         except (TypeError, ValueError):
             return True
 
+    # TODO: this is no longer used in python3
+    # https://docs.python.org/3/whatsnew/3.0.html#ordering-comparisons
+    # TODO: need to implement "rich comparisons" instead
+    # https://docs.python.org/3/reference/datamodel.html#object.__lt__
     def __cmp__(self, other):
 
         # treat non-integers as being less than myself
@@ -89,6 +100,12 @@ class GPC(object):
         assert myself == other
         return 0
 
+    def __lt__(self, other):
+        try:
+            return int(self) < int(other)
+        except (TypeError, ValueError):
+            return False
+
     def __hash__(self):
         return hash(self.value)
 
@@ -102,10 +119,8 @@ class GPC(object):
         return "GPC('%014d')" % self.value
 
     def __str__(self):
-        return str(unicode(self))
-
-    def __unicode__(self):
-        return u'%014d' % self.value
+        # return str('%14d' % self.value)
+        return str('{:014d}'.format(self.value))
 
     @property
     def data_str(self):
@@ -123,7 +138,7 @@ class GPC(object):
         Note that in this case the ``data_str`` value is the same as was
         originally provided to the constructor, but that isn't always the case.
         """
-        return unicode(int(self))[:-1]
+        return six.text_type(int(self))[:-1]
 
     @property
     def data_length(self):
@@ -145,5 +160,5 @@ class GPC(object):
         Returns the UPC as a somewhat more human-readable string.  Basically
         that just means the check digit is distinguished by a hyphen.
         """
-        upc = unicode(self)
+        upc = six.text_type(self)
         return "{0}-{1}".format(upc[:-1], upc[-1])
