@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 
 from __future__ import unicode_literals, absolute_import
 
@@ -8,18 +8,6 @@ from rattail.tests import DataTestCase
 
 class TestCustomer(DataTestCase):
 
-    def test_unicode(self):
-        customer = model.Customer()
-        self.assertEqual(unicode(customer), "")
-
-        customer = model.Customer(name=b"Fred Flintstone")
-        self.assertEqual(unicode(customer), "Fred Flintstone")
-
-        customer = model.Customer(people=[model.Person(first_name="Fred", last_name="Flintstone")])
-        self.session.add(customer)
-        self.session.flush()
-        self.assertEqual(unicode(customer), "Fred Flintstone")
-
     # TODO: this is duplicated in TestPerson
     def test_add_email_address(self):
         customer = model.Customer()
@@ -51,13 +39,3 @@ class TestCustomer(DataTestCase):
         self.assertEqual(len(customer.phones), 1)
         phone = customer.phones[0]
         self.assertEqual(phone.type, 'Work')
-
-
-class TestCustomerGroup(DataTestCase):
-
-    def test_unicode(self):
-        group = model.CustomerGroup()
-        self.assertEqual(unicode(group), "")
-
-        group = model.CustomerGroup(name=b"Loyal Shoppers")
-        self.assertEqual(unicode(group), "Loyal Shoppers")
