@@ -28,7 +28,7 @@ class TestSession(TestCase):
 
     def test_init_record_changes(self):
         if hasattr(db.Session, 'kw'):
-            self.assertFalse(db.Session.kw['rattail_record_changes'])
+            self.assertIsNone(db.Session.kw.get('rattail_record_changes'))
 
         session = db.Session()
         self.assertFalse(session.rattail_record_changes)
