@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 
 from __future__ import unicode_literals, absolute_import
 
@@ -8,11 +8,11 @@ import unittest
 import pytz
 from sqlalchemy import orm
 from mock import patch, Mock
-from fixture import TempIO
 
 from rattail.db import Session
 from rattail.importing import handlers, Importer
 from rattail.config import RattailConfig
+from rattail.util import OrderedDict
 from rattail.tests import RattailTestCase
 from rattail.tests.importing import ImporterTester
 from rattail.tests.importing.test_importers import MockImporter
@@ -358,16 +358,17 @@ class MockImportHandler(handlers.ImportHandler):
 
 class TestImportHandlerImportData(ImporterTester, unittest.TestCase):
 
-    sample_data = {
-        '16oz': {'upc': '00074305001161', 'description': "Apple Cider Vinegar 16oz"},
-        '32oz': {'upc': '00074305001321', 'description': "Apple Cider Vinegar 32oz"},
-        '1gal': {'upc': '00074305011283', 'description': "Apple Cider Vinegar 1gal"},
-    }
+    sample_data = OrderedDict([
+        ('16oz', {'upc': '00074305001161', 'description': "Apple Cider Vinegar 16oz"}),
+        ('32oz', {'upc': '00074305001321', 'description': "Apple Cider Vinegar 32oz"}),
+        ('1gal', {'upc': '00074305011283', 'description': "Apple Cider Vinegar 1gal"}),
+    ])
 
     def setUp(self):
         self.config = RattailConfig()
         self.handler = MockImportHandler(config=self.config)
         self.importer = MockImporter(config=self.config)
+        self.importer.handler = self.handler
 
     def import_data(self, **kwargs):
         # must modify our importer in-place since we need the handler to return
@@ -559,7 +560,7 @@ class TestFromSQLAlchemyHandler(unittest.TestCase):
         session = object()
         handler = handlers.FromSQLAlchemyHandler(host_session=session)
         kwargs = handler.get_importer_kwargs(None)
-        self.assertEqual(list(kwargs.iterkeys()), ['host_session'])
+        self.assertEqual(list(kwargs.keys()), ['host_session'])
         self.assertIs(kwargs['host_session'], session)
 
     def test_begin_host_transaction(self):
@@ -596,7 +597,7 @@ class TestToSQLAlchemyHandler(unittest.TestCase):
         session = object()
         handler = handlers.ToSQLAlchemyHandler(session=session)
         kwargs = handler.get_importer_kwargs(None)
-        self.assertEqual(list(kwargs.iterkeys()), ['session'])
+        self.assertEqual(list(kwargs.keys()), ['session'])
         self.assertIs(kwargs['session'], session)
 
     def test_begin_local_transaction(self):
