@@ -65,10 +65,20 @@ def data_diffs(local_data, host_data, fields=None):
     """
     if fields is None:
         fields = list(local_data)
+
     diffs = []
     for field in fields:
+
+        # maybe raise explicit error to indicate *which* dict is missing data
+        # (otherwise the comparison below raises "ambiguous" error about it)
+        if field not in local_data:
+            raise KeyError("key '{}' is missing from local_data".format(field))
+        if field not in host_data:
+            raise KeyError("key '{}' is missing from host_data".format(field))
+
         if local_data[field] != host_data[field]:
             diffs.append(field)
+
     return diffs
 
 
