@@ -1,33 +1,35 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2017 Lance Edgar
 #
 #  This file is part of Rattail.
 #
 #  Rattail is free software: you can redistribute it and/or modify it under the
-#  terms of the GNU Affero General Public License as published by the Free
-#  Software Foundation, either version 3 of the License, or (at your option)
-#  any later version.
+#  terms of the GNU General Public License as published by the Free Software
+#  Foundation, either version 3 of the License, or (at your option) any later
+#  version.
 #
 #  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
 #  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-#  FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for
-#  more details.
+#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+#  details.
 #
-#  You should have received a copy of the GNU Affero General Public License
-#  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
+#  You should have received a copy of the GNU General Public License along with
+#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
 """
 Vendor Invoices
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from decimal import Decimal
 
+import six
+
 from rattail.exceptions import RattailError
 from rattail.util import load_entry_points
 
@@ -87,6 +89,7 @@ class InvoiceParser(object):
         return int(value)
 
 
+@six.python_2_unicode_compatible
 class InvoiceParserNotFound(RattailError):
     """
     Exception raised when a vendor invoice parser is required, but cannot be
@@ -96,8 +99,8 @@ class InvoiceParserNotFound(RattailError):
     def __init__(self, key):
         self.key = key
 
-    def __unicode__(self):
-        return "Vendor invoice parser with key {0} cannot be located.".format(self.key)
+    def __str__(self):
+        return "Vendor invoice parser with key {} cannot be located.".format(self.key)
 
 
 def get_invoice_parsers():
